@@ -2,7 +2,7 @@ use std::{
     io,
     path::Path,
     slice::Chunks,
-    sync::atomic::{AtomicU64, AtomicUsize, Ordering},
+    sync::atomic::{AtomicUsize, Ordering},
 };
 
 use bstr::BStr;
@@ -19,7 +19,7 @@ use crate::{
         types::{Error, Options},
         Change, Conflict, EntryStatus, Outcome, VisitEntry,
     },
-    is_dir_to_mode, SymlinkCheck,
+    is_dir_to_mode, AtomicU64, SymlinkCheck,
 };
 
 /// Calculates the changes that need to be applied to an `index` to match the state of the `worktree` and makes them
@@ -92,7 +92,7 @@ where
     let entry_index_offset = range.start;
     let entries = &entries[range];
 
-    let _span = gix_features::trace::detail!("gix_status::index_as_worktree", 
+    let _span = gix_features::trace::detail!("gix_status::index_as_worktree",
                                              num_entries = entries.len(),
                                              chunk_size = chunk_size,
                                              thread_limit = ?thread_limit);
@@ -327,7 +327,7 @@ impl<'index> State<'_, 'index> {
     /// isn't really a race-condition to worry about. This also explains why removing the `return` here doesn't have an apparent effect.
     /// This entire branch here is just the optimization of "don't even look at index entries where the stat hasn't changed".
     /// If we don't have this optimization the result shouldn't change, our status implementation will just be super slow :D
-
+    ///
     /// We calculate whether this change is `racy_clean`, so if the last `timestamp` is before or the same as the `mtime` of the entry
     /// which is what `new_stat.is_racy(..)` does in the branch, and only if we are sure that there is no race condition
     /// do we `return` early. Since we don't `return` early we just do a full content comparison below,
@@ -335,13 +335,13 @@ impl<'index> State<'_, 'index> {
     ///
     /// If a file showed up as racily clean and didn't change then we don't need to do anything. After this status check is
     /// complete and the file won't show up as racily clean anymore, since it's mtime is now before the new timestamp.
-    /// However if the file did actually change then we really ran into one of those rare race conditions in that case we,
+    /// However, if the file did actually change then we really ran into one of those rare race conditions in that case we,
     /// and git does the same, set the size of the file in the index to 0. This will always make the file show up as changed.
     /// This adds the need to treat all files of size 0 in the index as changed. This is not quite right of course because 0 sized files
     /// could be entirely valid and unchanged. Therefore this only applies if the oid doesn't match the oid of an empty file,
     /// which is a constant.
     ///
-    /// Adapted from [here](https://github.com/Byron/gitoxide/pull/805#discussion_r1164676777).
+    /// Adapted from [here](https://github.com/GitoxideLabs/gitoxide/pull/805#discussion_r1164676777).
     fn compute_status<T, U, Find, E>(
         &mut self,
         entry: &gix_index::Entry,
@@ -356,8 +356,10 @@ impl<'index> State<'_, 'index> {
     {
         let worktree_path = match self.path_stack.verified_path(gix_path::from_bstr(rela_path).as_ref()) {
             Ok(path) => path,
-            Err(err) if err.kind() == io::ErrorKind::NotFound => return Ok(Some(Change::Removed.into())),
-            Err(err) => return Err(Error::Io(err)),
+            Err(err) if gix_fs::io_err::is_not_found(err.kind(), err.raw_os_error()) => {
+                return Ok(Some(Change::Removed.into()))
+            }
+            Err(err) => return Err(err.into()),
         };
         self.symlink_metadata_calls.fetch_add(1, Ordering::Relaxed);
         let metadata = match gix_index::fs::Metadata::from_path_no_follow(worktree_path) {
@@ -379,7 +381,9 @@ impl<'index> State<'_, 'index> {
                 }
             }
             Ok(metadata) => metadata,
-            Err(err) if err.kind() == io::ErrorKind::NotFound => return Ok(Some(Change::Removed.into())),
+            Err(err) if gix_fs::io_err::is_not_found(err.kind(), err.raw_os_error()) => {
+                return Ok(Some(Change::Removed.into()))
+            }
             Err(err) => {
                 return Err(err.into());
             }
@@ -424,12 +428,19 @@ impl<'index> State<'_, 'index> {
 
         self.buf.clear();
         self.buf2.clear();
+        let file_size_bytes = if cfg!(windows) && metadata.is_symlink() {
+            // symlinks on Windows seem to have a length of zero, so just pretend
+            // they have the correct length to avoid short-cutting, and enforce a full buffer check.
+            u64::from(entry.stat.size)
+        } else {
+            metadata.len()
+        };
         let fetch_data = ReadDataImpl {
             buf: &mut self.buf,
             path: worktree_path,
             rela_path,
             entry,
-            file_len: metadata.len(),
+            file_len: file_size_bytes,
             filter: &mut self.filter,
             attr_stack: &mut self.attr_stack,
             options: self.options,
@@ -440,7 +451,7 @@ impl<'index> State<'_, 'index> {
             odb_reads: self.odb_reads,
             odb_bytes: self.odb_bytes,
         };
-        let content_change = diff.compare_blobs(entry, metadata.len(), fetch_data, &mut self.buf2)?;
+        let content_change = diff.compare_blobs(entry, file_size_bytes, fetch_data, &mut self.buf2)?;
         // This file is racy clean! Set the size to 0 so we keep detecting this as the file is updated.
         if content_change.is_some() || executable_bit_changed {
             let set_entry_stat_size_zero = content_change.is_some() && racy_clean;
@@ -531,7 +542,8 @@ where
         let out = if is_symlink && self.options.fs.symlink {
             // conversion to bstr can never fail because symlinks are only used
             // on unix (by git) so no reason to use the try version here
-            let symlink_path = gix_path::into_bstr(std::fs::read_link(self.path)?);
+            let symlink_path =
+                gix_path::to_unix_separators_on_windows(gix_path::into_bstr(std::fs::read_link(self.path).unwrap()));
             self.buf.extend_from_slice(&symlink_path);
             self.worktree_bytes.fetch_add(self.buf.len() as u64, Ordering::Relaxed);
             Stream {
